@@ -20,8 +20,8 @@
 ;; and this notice must be preserved on all copies.
 
 ;;; Apr 4 '90 jgm	Ripped off of sun-fns.el
-(provide 'eterm-fns)
-(require 'eterm-mouse)
+;;(provide 'eterm-fns)
+;;(require 'eterm-mouse)
 ;;;
 ;;; Functions for manipulating via the mouse and mouse-map definitions
 ;;; for accessing them.  Also definitons of mouse menus.
@@ -50,12 +50,16 @@
 (defun indicate-region (&optional pause)
   "Bounce cursor to mark for cursor-pause-milliseconds and back again"
   (or pause (setq pause cursor-pause-milliseconds))
-  (let ((point (point)))
-    (goto-char (mark))
+  (let ((times 0))
+    (exchange-point-and-mark)
     (if (fboundp 'sit-for-millisecs)
 	(sit-for-millisecs pause)
       (sit-for 1))
-    (goto-char point)))
+    (exchange-point-and-mark)))
+
+;      (while (< times 20)
+;	(sit-for 0)
+;	(setq times (1+ times))))
 
 
 ;;;
